WaitForMode

Enum WaitForMode 

pub enum WaitForMode {
    Wait,
    Signal,
    Lock,
    Unlock,
}
The supported wait-for operation modes.

Variants



Wait

Wait for the next signal on the named channel.



Signal

Signal all current plain waiters on the named channel.



Lock

Acquire the named server-local lock, waiting in FIFO order when held.



Unlock

Release the named server-local lock.