pub struct KillSessionRequest {
pub target: SessionName,
pub kill_all_except_target: bool,
pub clear_alerts: bool,
}Expand description
Request payload for kill-session.
Fields
target: SessionNameThe exact target session name.
kill_all_except_target: boolWhether every other session should be destroyed instead of the target session.
clear_alerts: boolWhether the target session’s window alert flags should be cleared instead of destroying it.